



if not exist %LIBRARY_PREFIX%\\include\\doctest\\doctest.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\lib\\cmake\\doctest\\doctestConfig.cmake exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
